"""
RedXAuthCodes - Secure Authentication Code Generation and Verification

This package provides a secure way to generate and verify authentication codes with email integration
and subscription management capabilities. It can be used standalone or integrated with RedXSecurePayments.

Basic Usage:
    ```python
    from RedXAuthCodes import RedXCode, EmailService

    # Initialize services
    code_generator = RedXCode()
    email_service = EmailService()

    # Generate a verification code
    code_result = code_generator.Generate(
        email="user@example.com",
        length=8,  # Code length (default: 8)
        expiry_minutes=15  # Code expiration time (default: 15)
    )

    if code_result:
        code, created_at, expires_at = code_result
        # Send verification email
        email_service.send_verification_code(
            recipient_email="user@example.com",
            code=code
        )
    ```
"""

from auth_api.auth_service import AuthService as RedXCode
from auth_api.email_service import EmailService
from auth_api.subscription_manager import RedXSubscription as SubscriptionService

__version__ = "1.0.2"
__all__ = [
    'RedXCode',
    'EmailService',
    'SubscriptionService'
]